class Homebank < Formula
  desc "Manage your personal accounts at home"
  homepage "http://homebank.free.fr"
  # A mirror is used as primary URL because the official one is unstable.
  url "https://deb.debian.org/debian/pool/main/h/homebank/homebank_5.8.1.orig.tar.gz"
  mirror "http://homebank.free.fr/public/sources/homebank-5.8.1.tar.gz"
  sha256 "60c35feafe341aec8fed9de4b0a875dc0f5c1674c5f5804ff7190a6c6c53dc01"
  license "GPL-2.0-or-later"

  livecheck do
    url "https://deb.debian.org/debian/pool/main/h/homebank/"
    regex(/href=.*?homebank[._-]v?(\d+(?:\.\d+)+)\.orig\.t/i)
  end

  depends_on "intltool" => :build
  depends_on "pkg-config" => :build
  depends_on "adwaita-icon-theme"
  depends_on "fontconfig"
  depends_on "freetype"
  depends_on "gettext"
  depends_on "gtk+3"
  depends_on "hicolor-icon-theme"
  depends_on "libofx"
  depends_on "libsoup"

  uses_from_macos "perl"

  on_linux do
    depends_on "perl-xml-parser" => :build
  end

  # Fix scope of 'name' variable in rep-budget.c
  # upstream bug report, https://bugs.launchpad.net/homebank/+bug/2067543
  # nixpkg patch commit, https://github.com/NixOS/nixpkgs/commit/5b15ea1e00e33223d52c3aabb821de402265b326
  patch :DATA

  def install
    if OS.linux?
      ENV.prepend_path "PERL5LIB", Formula["perl-xml-parser"].libexec/"lib/perl5"
      ENV["INTLTOOL_PERL"] = Formula["perl"].bin/"perl"
    end

    system "./configure", "--disable-dependency-tracking",
                          "--prefix=#{prefix}", "--with-ofx"
    chmod 0755, "./install-sh"
    system "make", "install"
  end

  test do
    # homebank is a GUI application
    system bin/"homebank", "--help"
  end
end

__END__
diff --git a/src/rep-budget.c b/src/rep-budget.c
index eb5cce6..61e2e77 100644
--- a/src/rep-budget.c
+++ b/src/rep-budget.c
@@ -255,7 +255,7 @@ gint tmpmode;
 	}
 	else
 	{
-libname:
+libname: ;
 	gchar *name;

 		gtk_tree_model_get(model, iter,
